// license:BSD-3-Clause
// copyright-holders:Robbbert
#include "../mame/drivers/cps3.cpp"

class cps3_hbmame : public cps3_state
{
public:
	cps3_hbmame(const machine_config &mconfig, device_type type, const char *tag)
		: cps3_state(mconfig, type, tag)
		{ }

	DECLARE_DRIVER_INIT(jojon);
	DECLARE_DRIVER_INIT(jojoban);
	DECLARE_DRIVER_INIT(redeartno);
	DECLARE_DRIVER_INIT(sfiiin);
	DECLARE_DRIVER_INIT(sfiii2n);
	DECLARE_DRIVER_INIT(sfiii3n);
	DECLARE_MACHINE_RESET(redeartn);
	TIMER_CALLBACK_MEMBER(fastboot_timer_callback);

private:
	void hb_unscramble();
	emu_timer* m_fastboot_timer;
};

TIMER_CALLBACK_MEMBER(cps3_hbmame::fastboot_timer_callback)
{
	uint32_t *rom =  (uint32_t*)m_decrypted_gamerom;

	m_maincpu->set_state_int(SH2_PC, rom[0]);
	m_maincpu->set_state_int(SH2_R15, rom[1]);
	m_maincpu->set_state_int(SH2_VBR, 0x6000000);
}

void cps3_hbmame::hb_unscramble()
{
	uint8_t *rom = memregion("old4")->base();
	uint8_t *simm0 = memregion("simm1.0")->base();
	uint8_t *simm1 = memregion("simm1.1")->base();
	uint8_t *simm2 = memregion("simm1.2")->base();
	uint8_t *simm3 = memregion("simm1.3")->base();
	uint32_t i, j = 0;
	for (i = 0; i < 0x200000; i++)
	{
		simm3[i] = rom[j++];
		simm2[i] = rom[j++];
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}

	if (memregion("simm2.0"))
	{
		simm0 = memregion("simm2.0")->base();
		simm1 = memregion("simm2.1")->base();
		simm2 = memregion("simm2.2")->base();
		simm3 = memregion("simm2.3")->base();
		for (i = 0; i < 0x200000; i++)
		{
			simm3[i] = rom[j++];
			simm2[i] = rom[j++];
			simm1[i] = rom[j++];
			simm0[i] = rom[j++];
		}
	}

	j = 0;
	rom = memregion("old5")->base();
	simm0 = memregion("simm3.0")->base();
	simm1 = memregion("simm3.1")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}
	simm0 = memregion("simm3.2")->base();
	simm1 = memregion("simm3.3")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}
	simm0 = memregion("simm3.4")->base();
	simm1 = memregion("simm3.5")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}
	simm0 = memregion("simm3.6")->base();
	simm1 = memregion("simm3.7")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}
	simm0 = memregion("simm4.0")->base();
	simm1 = memregion("simm4.1")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}
	simm0 = memregion("simm4.2")->base();
	simm1 = memregion("simm4.3")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}
	simm0 = memregion("simm4.4")->base();
	simm1 = memregion("simm4.5")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}
	simm0 = memregion("simm4.6")->base();
	simm1 = memregion("simm4.7")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}
	simm0 = memregion("simm5.0")->base();
	simm1 = memregion("simm5.1")->base();
	for (i = 0; i < 0x200000; i++)
	{
		simm1[i] = rom[j++];
		simm0[i] = rom[j++];
	}

	if (memregion("simm5.2"))
	{
		simm0 = memregion("simm5.2")->base();
		simm1 = memregion("simm5.3")->base();
		for (i = 0; i < 0x200000; i++)
		{
			simm1[i] = rom[j++];
			simm0[i] = rom[j++];
		}
	}

	if (memregion("simm5.4"))
	{
		simm0 = memregion("simm5.4")->base();
		simm1 = memregion("simm5.5")->base();
		for (i = 0; i < 0x200000; i++)
		{
			simm1[i] = rom[j++];
			simm0[i] = rom[j++];
		}
		simm0 = memregion("simm5.6")->base();
		simm1 = memregion("simm5.7")->base();
		for (i = 0; i < 0x200000; i++)
		{
			simm1[i] = rom[j++];
			simm0[i] = rom[j++];
		}
	}

	if (memregion("simm6.0"))
	{
		simm0 = memregion("simm6.0")->base();
		simm1 = memregion("simm6.1")->base();
		for (i = 0; i < 0x200000; i++)
		{
			simm1[i] = rom[j++];
			simm0[i] = rom[j++];
		}
		simm0 = memregion("simm6.2")->base();
		simm1 = memregion("simm6.3")->base();
		for (i = 0; i < 0x200000; i++)
		{
			simm1[i] = rom[j++];
			simm0[i] = rom[j++];
		}
		simm0 = memregion("simm6.4")->base();
		simm1 = memregion("simm6.5")->base();
		for (i = 0; i < 0x200000; i++)
		{
			simm1[i] = rom[j++];
			simm0[i] = rom[j++];
		}
		simm0 = memregion("simm6.6")->base();
		simm1 = memregion("simm6.7")->base();
		for (i = 0; i < 0x200000; i++)
		{
			simm1[i] = rom[j++];
			simm0[i] = rom[j++];
		}
	}
}

DRIVER_INIT_MEMBER( cps3_hbmame, jojon )
{
	hb_unscramble();
	DRIVER_INIT_CALL(jojo);
}

DRIVER_INIT_MEMBER( cps3_hbmame, jojoban )
{
	hb_unscramble();
	DRIVER_INIT_CALL(jojoba);
}

DRIVER_INIT_MEMBER( cps3_hbmame, redeartno )
{
	hb_unscramble();
	DRIVER_INIT_CALL(redearth);
}

DRIVER_INIT_MEMBER( cps3_hbmame, sfiiin )
{
	hb_unscramble();
	DRIVER_INIT_CALL(sfiii);
}

DRIVER_INIT_MEMBER( cps3_hbmame, sfiii2n )
{
	hb_unscramble();
	DRIVER_INIT_CALL(sfiii2);
}

DRIVER_INIT_MEMBER( cps3_hbmame, sfiii3n )
{
	hb_unscramble();
	DRIVER_INIT_CALL(sfiii3);
}

MACHINE_RESET_MEMBER( cps3_hbmame, redeartn )
{
	m_current_table_address = -1;

	m_fastboot_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(cps3_hbmame::fastboot_timer_callback),this));
	m_fastboot_timer->adjust(attotime::zero);

	// copy data from flashroms back into user regions + decrypt into regions we execute/draw from.
	copy_from_nvram();
}

static MACHINE_CONFIG_DERIVED_CLASS( redeartn, redearth, cps3_hbmame )
	MCFG_MACHINE_RESET_OVERRIDE(cps3_hbmame, redeartn)
MACHINE_CONFIG_END

static INPUT_PORTS_START ( cps3_ren )
	PORT_INCLUDE ( cps3 )
	PORT_MODIFY("INPUTS")
	PORT_BIT( 0x10000000, IP_ACTIVE_LOW, IPT_START1 ) PORT_NAME("P1 Start / Change Orb")
	PORT_BIT( 0x20000000, IP_ACTIVE_LOW, IPT_START2 ) PORT_NAME("P2 Start / Change Orb")

	PORT_START("REG")
	PORT_DIPNAME( 0x0000000f, 0x00000000, DEF_STR( Region ) )
	PORT_DIPSETTING( 0x00000000, "Default" )
	// none of these do anything
	//PORT_DIPSETTING( 0x00000001, DEF_STR( Japan ) )
	//PORT_DIPSETTING( 0x00000002, DEF_STR( Asia ) )
	//PORT_DIPSETTING( 0x00000003, DEF_STR( Europe ) )
	//PORT_DIPSETTING( 0x00000004, DEF_STR( USA ) )
	//PORT_DIPSETTING( 0x00000005, "Hispanic" )
	//PORT_DIPSETTING( 0x00000006, "Brazil" )
	//PORT_DIPSETTING( 0x00000007, "Oceania" )
	//PORT_DIPSETTING( 0x00000008, "Asia NCD" )

	PORT_START("VER")
	PORT_DIPNAME( 0x000000f0, 0x00000060, DEF_STR( Version ) )
	PORT_DIPSETTING( 0x00000060, DEF_STR( Normal ) )
	// none of these do anything
	//PORT_DIPSETTING( 0x00000010, "Character Check" )
	//PORT_DIPSETTING( 0x00000020, "Publicity" )
	//PORT_DIPSETTING( 0x00000030, "Location Test" )
	//PORT_DIPSETTING( 0x00000040, "Show" )
	//PORT_DIPSETTING( 0x00000050, "???" )
INPUT_PORTS_END



ROM_START( jojobbh2 )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "jojoba_euro_nocd.29f400.u2", 0x000000, 0x080000, CRC(1ee2d679) SHA1(9e129b454a376606b3f7e8aec64de425cf9c635c) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10bh2",  0x000000, 0x800000, CRC(45e18e22) SHA1(e49fe9659852346ad36907b7ddd30b26ae44f309) )
	ROM_LOAD( "20",  0x800000, 0x800000, CRC(1293892b) SHA1(b1beafac1a9c4b6d0640658af8a3eb359e76eb25) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(d25c5005) SHA1(93a19a14783d604bb42feffbe23eb370d11281e8) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(51bb3dba) SHA1(39e95a05882909820b3efa6a3b457b8574012638) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(94dc26d4) SHA1(5ae2815142972f322886eea4885baf2b82563ab1) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(1c53ee62) SHA1(e096bf3cb6fbc3d45955787b8f3213abcd76d120) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(36e416ed) SHA1(58d0e95cc13f39bc171165468ce72f4f17b8d8d6) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(eedf19ca) SHA1(a7660bf9ff87911afb4f83b64456245059986830) )
ROM_END

ROM_START( jojobbss )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "jojoba_japan_nocd.29f400.u2", 0x000000, 0x080000, CRC(4dab19f5) SHA1(ba07190e7662937fc267f07285c51e99a45c061e) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10bbss",  0x000000, 0x800000, CRC(84f44fbc) SHA1(4727e24fe00e88a82b67f981643480e15224ae18) )
	ROM_LOAD( "20",  0x800000, 0x800000, CRC(1293892b) SHA1(b1beafac1a9c4b6d0640658af8a3eb359e76eb25) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(d25c5005) SHA1(93a19a14783d604bb42feffbe23eb370d11281e8) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(51bb3dba) SHA1(39e95a05882909820b3efa6a3b457b8574012638) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(94dc26d4) SHA1(5ae2815142972f322886eea4885baf2b82563ab1) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(1c53ee62) SHA1(e096bf3cb6fbc3d45955787b8f3213abcd76d120) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(36e416ed) SHA1(58d0e95cc13f39bc171165468ce72f4f17b8d8d6) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(eedf19ca) SHA1(a7660bf9ff87911afb4f83b64456245059986830) )
ROM_END

ROM_START( jojobpow )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "jojoba_japan_nocd.29f400.u2", 0x000000, 0x080000, CRC(4dab19f5) SHA1(ba07190e7662937fc267f07285c51e99a45c061e) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10bpow",  0x000000, 0x800000, CRC(d616f8d4) SHA1(665c353fd32183c0bf18b70a48f84f469c00fddc) )
	ROM_LOAD( "20",  0x800000, 0x800000, CRC(1293892b) SHA1(b1beafac1a9c4b6d0640658af8a3eb359e76eb25) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(d25c5005) SHA1(93a19a14783d604bb42feffbe23eb370d11281e8) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(51bb3dba) SHA1(39e95a05882909820b3efa6a3b457b8574012638) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(94dc26d4) SHA1(5ae2815142972f322886eea4885baf2b82563ab1) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(1c53ee62) SHA1(e096bf3cb6fbc3d45955787b8f3213abcd76d120) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(36e416ed) SHA1(58d0e95cc13f39bc171165468ce72f4f17b8d8d6) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(eedf19ca) SHA1(a7660bf9ff87911afb4f83b64456245059986830) )
ROM_END


ROM_START( jojonbss )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "jojo_asia_nocd.29f400.u2", 0x000000, 0x080000, CRC(05b4f953) SHA1(c746c7bb5359acc9adced817cb4870b1912eaefd) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10bss",  0x0000000, 0x800000, CRC(fccbce04) SHA1(cd4d429620afdd1924ceb33f1a435c9de91453c3) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(0e1daddf) SHA1(34bb4e0fb86258095a7b20f60174453195f3735a) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(1d99181b) SHA1(25c216de16cefac2d5892039ad23d07848a457e6) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(6889fbda) SHA1(53a51b993d319d81a604cdf70b224955eacb617e) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(8069f9de) SHA1(7862ee104a2e9034910dd592687b40ebe75fa9ce) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(9c426823) SHA1(1839dccc7943a44063e8cb2376cd566b24e8b797) )
	ROM_LOAD( "50",  0x2000000, 0x400000, CRC(1c749cc7) SHA1(23df741360476d8035c68247e645278fbab53b59) )
ROM_END

ROM_START( jojonpow )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "jojo_asia_nocd.29f400.u2", 0x000000, 0x080000, CRC(05b4f953) SHA1(c746c7bb5359acc9adced817cb4870b1912eaefd) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10pow",  0x0000000, 0x800000, CRC(dd5723e1) SHA1(85adee2f633fd5438c00d2c8c9fde0c4d8a7282f) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(0e1daddf) SHA1(34bb4e0fb86258095a7b20f60174453195f3735a) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(1d99181b) SHA1(25c216de16cefac2d5892039ad23d07848a457e6) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(6889fbda) SHA1(53a51b993d319d81a604cdf70b224955eacb617e) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(8069f9de) SHA1(7862ee104a2e9034910dd592687b40ebe75fa9ce) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(9c426823) SHA1(1839dccc7943a44063e8cb2376cd566b24e8b797) )
	ROM_LOAD( "50",  0x2000000, 0x400000, CRC(1c749cc7) SHA1(23df741360476d8035c68247e645278fbab53b59) )
ROM_END


ROM_START( redeartn )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "redearthn_asia_nocd.29f400.u2", 0x000000, 0x080000, CRC(db09f27c) SHA1(f2d299cda7cda175b4218526a15f12560654d97f) )

	ROM_REGION( 0x200000, "simm1.0", 0 )
	ROM_LOAD( "redeartn-simm1.0", 0x00000, 0x200000, CRC(cad468f8) SHA1(b3aa4f7d3fae84e8821417ccde9528d3eda2b7a6) )
	ROM_REGION( 0x200000, "simm1.1", 0 )
	ROM_LOAD( "redeartn-simm1.1", 0x00000, 0x200000, CRC(e9721d89) SHA1(5c63d10bdbce52d50b6dde14d4a0f1369383d656) )
	ROM_REGION( 0x200000, "simm1.2", 0 )
	ROM_LOAD( "redeartn-simm1.2", 0x00000, 0x200000, CRC(2889ec98) SHA1(a94310eb4777f908d87e9d90969db8504b4140ff) )
	ROM_REGION( 0x200000, "simm1.3", 0 )
	ROM_LOAD( "redeartn-simm1.3", 0x00000, 0x200000, CRC(5a6cd148) SHA1(d65c6e8378a91828474a16a3bbcd13c4b3b15f13) )

	ROM_REGION( 0x200000, "simm3.0", 0 )
	ROM_LOAD( "redeartn-simm3.0", 0x00000, 0x200000, CRC(83350cc5) SHA1(922b1abf80a4a89f35279b66311a7369d3965bd0) )
	ROM_REGION( 0x200000, "simm3.1", 0 )
	ROM_LOAD( "redeartn-simm3.1", 0x00000, 0x200000, CRC(56734de6) SHA1(75699fa6efe5bec335e4b02e15b3c45726b68fa8) )
	ROM_REGION( 0x200000, "simm3.2", 0 )
	ROM_LOAD( "redeartn-simm3.2", 0x00000, 0x200000, CRC(800ea0f1) SHA1(33871ab56dc1cd24441389d53e43fb8e43b149d9) )
	ROM_REGION( 0x200000, "simm3.3", 0 )
	ROM_LOAD( "redeartn-simm3.3", 0x00000, 0x200000, CRC(97e9146c) SHA1(ab7744709615081440bee72f4080d6fd5b938668) )
	ROM_REGION( 0x200000, "simm3.4", 0 )
	ROM_LOAD( "redeartn-simm3.4", 0x00000, 0x200000, CRC(0cb1d648) SHA1(7042a590c2b7ec55323062127e254da3cdc790a1) )
	ROM_REGION( 0x200000, "simm3.5", 0 )
	ROM_LOAD( "redeartn-simm3.5", 0x00000, 0x200000, CRC(7a1099f0) SHA1(c6a92ec86eb24485f1db530e0e78f647e8432231) )
	ROM_REGION( 0x200000, "simm3.6", 0 )
	ROM_LOAD( "redeartn-simm3.6", 0x00000, 0x200000, CRC(aeff8f54) SHA1(fd760e237c2e5fb2da45e32a1c12fd3defb4c3e4) )
	ROM_REGION( 0x200000, "simm3.7", 0 )
	ROM_LOAD( "redeartn-simm3.7", 0x00000, 0x200000, CRC(f770acd0) SHA1(4b3ccb6f91568f95f04ede6c574144918d131201) )

	ROM_REGION( 0x200000, "simm4.0", 0 )
	ROM_LOAD( "redeartn-simm4.0", 0x00000, 0x200000, CRC(301e56f2) SHA1(4847d971bff70a2aeed4599e1201c7ec9677da60) )
	ROM_REGION( 0x200000, "simm4.1", 0 )
	ROM_LOAD( "redeartn-simm4.1", 0x00000, 0x200000, CRC(2048e103) SHA1(b21f95b05cd99749bd3f25cc71b2671c2026847b) )
	ROM_REGION( 0x200000, "simm4.2", 0 )
	ROM_LOAD( "redeartn-simm4.2", 0x00000, 0x200000, CRC(c9433455) SHA1(63a269d76bac332c2e991d0f6a20c35e0e88680a) )
	ROM_REGION( 0x200000, "simm4.3", 0 )
	ROM_LOAD( "redeartn-simm4.3", 0x00000, 0x200000, CRC(c02171a8) SHA1(2e9228729b27a6113d9f2e42af310a834979f714) )
	ROM_REGION( 0x200000, "simm4.4", 0 )
	ROM_LOAD( "redeartn-simm4.4", 0x00000, 0x200000, CRC(2ddbf276) SHA1(b232baaa8edc8db18f8a3bdcc2d38fe984a94a34) )
	ROM_REGION( 0x200000, "simm4.5", 0 )
	ROM_LOAD( "redeartn-simm4.5", 0x00000, 0x200000, CRC(fea820a6) SHA1(55ee8ef95751f5a509fb126513e1b2a70a3414e5) )
	ROM_REGION( 0x200000, "simm4.6", 0 )
	ROM_LOAD( "redeartn-simm4.6", 0x00000, 0x200000, CRC(c7528df1) SHA1(aa312f80c2d7759d18d1aa8d416cf932b2850824) )
	ROM_REGION( 0x200000, "simm4.7", 0 )
	ROM_LOAD( "redeartn-simm4.7", 0x00000, 0x200000, CRC(2449cf3b) SHA1(c60d8042136d74e547f668ad787cae529c42eed9) )

	ROM_REGION( 0x200000, "simm5.0", 0 )
	ROM_LOAD( "redeartn-simm5.0", 0x00000, 0x200000, CRC(424451b9) SHA1(250fb92254c9e7ff5bc8dbeea5872f8a771dc9bd) )
	ROM_REGION( 0x200000, "simm5.1", 0 )
	ROM_LOAD( "redeartn-simm5.1", 0x00000, 0x200000, CRC(9b8cb56b) SHA1(2ff1081dc99bb7c2f1e036f4c112137c96b83d23) )
ROM_END

ROM_START( redearex )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "redearth_euro.29f400.u2", 0x000000, 0x080000, CRC(02e0f336) SHA1(acc37e830dfeb9674f5a0fb24f4cc23217ae4ff5) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", 0 )
	ROM_LOAD( "10ex",  0x000000,  0x800000, CRC(e44131ad) SHA1(1b395edd8c0cb2705a1bdbb8df75e6d218d8e379) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", 0 )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(074cab4d) SHA1(4cb6cc9cce3b1a932b07058a5d723b3effa23fcf) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(14e2cad4) SHA1(9958a4e315e4476e4791a6219b93495413c7b751) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(72d98890) SHA1(f40926c52cb7a71b0ef0027a0ea38bbc7e8b31b0) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(88ccb33c) SHA1(1e7af35d186d0b4e45b6c27458ddb9cfddd7c9bc) )
	ROM_LOAD( "50",  0x2000000, 0x400000, CRC(2f5b44bd) SHA1(7ffdbed5b6899b7e31414a0828e04543d07435e4) )
ROM_END

ROM_START( redeartno )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "redearth_euro.29f400.u2", 0x000000, 0x080000, CRC(02e0f336) SHA1(acc37e830dfeb9674f5a0fb24f4cc23217ae4ff5) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", 0 )
	ROM_LOAD( "10",  0x000000,  0x800000, CRC(68188016) SHA1(93aaac08cb5566c33aabc16457085b0a36048019) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", 0 )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(074cab4d) SHA1(4cb6cc9cce3b1a932b07058a5d723b3effa23fcf) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(14e2cad4) SHA1(9958a4e315e4476e4791a6219b93495413c7b751) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(72d98890) SHA1(f40926c52cb7a71b0ef0027a0ea38bbc7e8b31b0) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(88ccb33c) SHA1(1e7af35d186d0b4e45b6c27458ddb9cfddd7c9bc) )
	ROM_LOAD( "50",  0x2000000, 0x400000, CRC(2f5b44bd) SHA1(7ffdbed5b6899b7e31414a0828e04543d07435e4) )
ROM_END


ROM_START( sfiiibhp )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii_asia_nocd.29f400.u2", 0x000000, 0x080000, CRC(73e32463) SHA1(45d144e533e4b20cc5a744ca4f618e288430c601) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", 0 )
	ROM_LOAD( "10bhp",  0x0000000, 0x800000, CRC(cebd13a2) SHA1(18017d798448f6271f5c7b07325e0410b5d55f0d) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", 0 )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(98c2d07c) SHA1(604ce4a16170847c10bc233a47a47a119ce170f7) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(7115a396) SHA1(b60a74259e3c223138e66e68a3f6457694a0c639) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(839f0972) SHA1(844e43fcc157b7c774044408bfe918c49e174cdb) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(8a8b252c) SHA1(9ead4028a212c689d7a25746fbd656dca6f938e8) )
	ROM_LOAD( "50",  0x2000000, 0x400000, CRC(58933dc2) SHA1(1f1723be676a817237e96b6e20263b935c59daae) )
ROM_END

ROM_START( sfiiipmp )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii_asia_nocd.29f400.u2", 0x000000, 0x080000, CRC(73e32463) SHA1(45d144e533e4b20cc5a744ca4f618e288430c601) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", 0 )
	ROM_LOAD( "10pmp",  0x0000000, 0x800000, CRC(41ed9e7b) SHA1(91684a1ecada9971eddf5ca6ace95f7110ba165b) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", 0 )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(98c2d07c) SHA1(604ce4a16170847c10bc233a47a47a119ce170f7) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(7115a396) SHA1(b60a74259e3c223138e66e68a3f6457694a0c639) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(839f0972) SHA1(844e43fcc157b7c774044408bfe918c49e174cdb) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(8a8b252c) SHA1(9ead4028a212c689d7a25746fbd656dca6f938e8) )
	ROM_LOAD( "50",  0x2000000, 0x400000, CRC(58933dc2) SHA1(1f1723be676a817237e96b6e20263b935c59daae) )
ROM_END


ROM_START( sfiii2bh )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii2_asia_nocd.29f400.u2", 0x000000, 0x080000, CRC(fd297c0d) SHA1(4323deda2789f104b53f32a663196ec16de73215) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", 0 )
	ROM_LOAD( "10bh",  0x0000000, 0x800000, CRC(503d6401) SHA1(bf352cada35fd5c9927d265fcc04a068ed015e57) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(38090460) SHA1(aaade89b8ccdc9154f97442ca35703ec538fe8be) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", 0 )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(77c197c0) SHA1(944381161462e65de7ae63a656658f3fbe44727a) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(7470a6f2) SHA1(850b2e20afe8a5a1f0d212d9abe002cb5cf14d22) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(01a85ced) SHA1(802df3274d5f767636b2785606e0558f6d3b9f13) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(fb346d74) SHA1(57570f101a170aa7e83e84e4b7cbdc63a11a486a) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(32f79449) SHA1(44b1f2a640ab4abc23ff47e0edd87fbd0b345c06) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(1102b8eb) SHA1(c7dd2ee3a3214c6ec47a03fe3e8c941775d57f76) )
ROM_END

ROM_START( sfiii2np )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii2_asia_nocd.29f400.u2", 0x000000, 0x080000, CRC(fd297c0d) SHA1(4323deda2789f104b53f32a663196ec16de73215) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", 0 )
	ROM_LOAD( "10p",  0x0000000, 0x800000, CRC(ff5a016f) SHA1(0fef232f3ff9a0ef2225b934b283118b53b2f26e) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(38090460) SHA1(aaade89b8ccdc9154f97442ca35703ec538fe8be) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", 0 )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(77c197c0) SHA1(944381161462e65de7ae63a656658f3fbe44727a) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(7470a6f2) SHA1(850b2e20afe8a5a1f0d212d9abe002cb5cf14d22) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(01a85ced) SHA1(802df3274d5f767636b2785606e0558f6d3b9f13) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(fb346d74) SHA1(57570f101a170aa7e83e84e4b7cbdc63a11a486a) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(32f79449) SHA1(44b1f2a640ab4abc23ff47e0edd87fbd0b345c06) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(1102b8eb) SHA1(c7dd2ee3a3214c6ec47a03fe3e8c941775d57f76) )
ROM_END

ROM_START( sfiii2pl )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii2_asia_nocd.29f400.u2", 0x000000, 0x080000, CRC(fd297c0d) SHA1(4323deda2789f104b53f32a663196ec16de73215) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", 0 )
	ROM_LOAD( "10pl",  0x0000000, 0x800000, CRC(beb7b483) SHA1(451e37490dccd7ae11c1bd6f7ba236af7d54b342) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(38090460) SHA1(aaade89b8ccdc9154f97442ca35703ec538fe8be) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", 0 )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(77c197c0) SHA1(944381161462e65de7ae63a656658f3fbe44727a) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(7470a6f2) SHA1(850b2e20afe8a5a1f0d212d9abe002cb5cf14d22) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(01a85ced) SHA1(802df3274d5f767636b2785606e0558f6d3b9f13) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(fb346d74) SHA1(57570f101a170aa7e83e84e4b7cbdc63a11a486a) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(32f79449) SHA1(44b1f2a640ab4abc23ff47e0edd87fbd0b345c06) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(1102b8eb) SHA1(c7dd2ee3a3214c6ec47a03fe3e8c941775d57f76) )
ROM_END


ROM_START( sfiii3an )
	ROM_REGION32_BE( 0x080000, "bios", 0 ) /* bios region */
	ROM_LOAD( "sfiii3_japan_nocd.29f400.u2", 0x000000, 0x080000, CRC(1edc6366) SHA1(60b4b9adeb030a33059d74fdf03873029e465b52) )

	ROM_REGION( 0x200000, "simm1.0", 0 )
	ROM_LOAD( "sfiii3n-simm1.0", 0x000000, 0x200000, CRC(11dfd3cd) SHA1(dba1f77c46e80317e3279298411154dfb6db2309) )
	ROM_REGION( 0x200000, "simm1.1", 0 )
	ROM_LOAD( "sfiii3n-simm1.1", 0x000000, 0x200000, CRC(c50585e6) SHA1(a289237957ea1c7f58b1c65e24c54ceb34cb1712) )
	ROM_REGION( 0x200000, "simm1.2", 0 )
	ROM_LOAD( "sfiii3n-simm1.2", 0x000000, 0x200000, CRC(8e011d9b) SHA1(e0861bcd3c4f865474d7ce47aa9eeec7b3d28da6) )
	ROM_REGION( 0x200000, "simm1.3", 0 )
	ROM_LOAD( "sfiii3n-simm1.3", 0x000000, 0x200000, CRC(dca8d92f) SHA1(7cd241641c943df446e2c75b88b5cf2d2ebf7b2e) )

	ROM_REGION( 0x200000, "simm2.0", 0 )
	ROM_LOAD( "sfiii3-simm2.0", 0x00000, 0x200000, CRC(06eb969e) SHA1(d89f6a6585b76692d57d337f0f8186398fb056da) )
	ROM_REGION( 0x200000, "simm2.1", 0 )
	ROM_LOAD( "sfiii3-simm2.1", 0x00000, 0x200000, CRC(e7039f82) SHA1(8e81e66b5a4f45ae14b070a491bde47a6a74499f) )
	ROM_REGION( 0x200000, "simm2.2", 0 )
	ROM_LOAD( "sfiii3-simm2.2", 0x00000, 0x200000, CRC(645c96f7) SHA1(06d5a54874d4bf100b776131ec9060da209ad037) )
	ROM_REGION( 0x200000, "simm2.3", 0 )
	ROM_LOAD( "sfiii3-simm2.3", 0x00000, 0x200000, CRC(610efab1) SHA1(bbc21ed6ff6220ff6017a3f02ebd9a341fbc9040) )

	ROM_REGION( 0x200000, "simm3.0", 0 )
	ROM_LOAD( "sfiii3-simm3.0", 0x00000, 0x200000, CRC(7baa1f79) SHA1(3f409df28c24dd7221966b5340d59898ea756b6f) )
	ROM_REGION( 0x200000, "simm3.1", 0 )
	ROM_LOAD( "sfiii3-simm3.1", 0x00000, 0x200000, CRC(234bf8fe) SHA1(2191781ae4d726cab28de97f27efa4a13f3bdd69) )
	ROM_REGION( 0x200000, "simm3.2", 0 )
	ROM_LOAD( "sfiii3-simm3.2", 0x00000, 0x200000, CRC(d9ebc308) SHA1(af6a0dca77e5181c9f20533a06760a782c5fd51d) )
	ROM_REGION( 0x200000, "simm3.3", 0 )
	ROM_LOAD( "sfiii3-simm3.3", 0x00000, 0x200000, CRC(293cba77) SHA1(294604cacdc24261aec4d39e489de91c41fa1758) )
	ROM_REGION( 0x200000, "simm3.4", 0 )
	ROM_LOAD( "sfiii3-simm3.4", 0x00000, 0x200000, CRC(6055e747) SHA1(3813852c5a4a5355ef739ca8f0913bbd390b984b) )
	ROM_REGION( 0x200000, "simm3.5", 0 )
	ROM_LOAD( "sfiii3-simm3.5", 0x00000, 0x200000, CRC(499aa6fc) SHA1(5b9b6eab3e99ff3e1d7c1f50b9d8bc6a81f3f8a9) )
	ROM_REGION( 0x200000, "simm3.6", 0 )
	ROM_LOAD( "sfiii3-simm3.6", 0x00000, 0x200000, CRC(6c13879e) SHA1(de189b0b8f42bc7dd89983e62bc2ecb4237b3277) )
	ROM_REGION( 0x200000, "simm3.7", 0 )
	ROM_LOAD( "sfiii3-simm3.7", 0x00000, 0x200000, CRC(cf4f8ede) SHA1(e0fb68fcb0e445f824c62fa828d6e1dcd7e3683a) )

	ROM_REGION( 0x200000, "simm4.0", 0 )
	ROM_LOAD( "sfiii3-simm4.0", 0x00000, 0x200000, CRC(091fd5ba) SHA1(3327ad7c2623c119bf728af717ea2ce3b74673a9) )
	ROM_REGION( 0x200000, "simm4.1", 0 )
	ROM_LOAD( "sfiii3-simm4.1", 0x00000, 0x200000, CRC(0bca8917) SHA1(b7b284e2f16f46d46bcfaae779b232c5b980924f) )
	ROM_REGION( 0x200000, "simm4.2", 0 )
	ROM_LOAD( "sfiii3-simm4.2", 0x00000, 0x200000, CRC(a0fd578b) SHA1(100c9db9f00ecd88d518076f5a0822e6ac3695b3) )
	ROM_REGION( 0x200000, "simm4.3", 0 )
	ROM_LOAD( "sfiii3-simm4.3", 0x00000, 0x200000, CRC(4bf8c699) SHA1(2c0b4288b5ebc5e54d9e782dfc39eb8c78fd4c21) )
	ROM_REGION( 0x200000, "simm4.4", 0 )
	ROM_LOAD( "sfiii3-simm4.4", 0x00000, 0x200000, CRC(137b8785) SHA1(56a579520a8ce2abbf36be57777f024e80474eee) )
	ROM_REGION( 0x200000, "simm4.5", 0 )
	ROM_LOAD( "sfiii3-simm4.5", 0x00000, 0x200000, CRC(4fb70671) SHA1(9aba83c18cfc099a5ce18793119bff0c2b9c777f) )
	ROM_REGION( 0x200000, "simm4.6", 0 )
	ROM_LOAD( "sfiii3-simm4.6", 0x00000, 0x200000, CRC(832374a4) SHA1(c84629e32fbf47cb7b5b4ee7555bfc2ac9b3857f) )
	ROM_REGION( 0x200000, "simm4.7", 0 )
	ROM_LOAD( "sfiii3-simm4.7", 0x00000, 0x200000, CRC(1c88576d) SHA1(0f039944d0c2305999ed5dbd351c3eb87812dc3b) )

	ROM_REGION( 0x200000, "simm5.0", 0 )
	ROM_LOAD( "sfiii3-simm5.0", 0x00000, 0x200000, CRC(c67d9190) SHA1(d265475244099d0ec153059986f3445c7bd910a3) )
	ROM_REGION( 0x200000, "simm5.1", 0 )
	ROM_LOAD( "sfiii3-simm5.1", 0x00000, 0x200000, CRC(6cb79868) SHA1(c94237f30e05bfcb2e23945530c812d9e4c73416) )
	ROM_REGION( 0x200000, "simm5.2", 0 )
	ROM_LOAD( "sfiii3-simm5.2", 0x00000, 0x200000, CRC(df69930e) SHA1(c76b7c559a1d5558138afbc796249efa2f49f6a8) )
	ROM_REGION( 0x200000, "simm5.3", 0 )
	ROM_LOAD( "sfiii3-simm5.3", 0x00000, 0x200000, CRC(333754e0) SHA1(4c18a569c26524a492ecd6f4c8b3c8e803a077d3) )
	ROM_REGION( 0x200000, "simm5.4", 0 )
	ROM_LOAD( "sfiii3-simm5.4", 0x00000, 0x200000, CRC(78f6d417) SHA1(a69577cc5399fcf0a24548661168f27f3e7e8e40) )
	ROM_REGION( 0x200000, "simm5.5", 0 )
	ROM_LOAD( "sfiii3-simm5.5", 0x00000, 0x200000, CRC(8ccad9b1) SHA1(f8bda399f87be2497b7ac39e9661f9863bf4f873) )
	ROM_REGION( 0x200000, "simm5.6", 0 )
	ROM_LOAD( "sfiii3n-simm5.6", 0x000000, 0x200000, CRC(85de59e5) SHA1(748b5c91f15777b85d8c1d35b685cd90d3185ec6) )
	ROM_REGION( 0x200000, "simm5.7", 0 )
	ROM_LOAD( "sfiii3n-simm5.7", 0x000000, 0x200000, CRC(ee7e29b3) SHA1(63dc30c6904ca2f58d229249bee5eef51fafa158) )

	ROM_REGION( 0x200000, "simm6.0", 0 )
	ROM_LOAD( "sfiii3-simm6.0", 0x00000, 0x200000, CRC(8da69042) SHA1(fd3d08295342635b2136e48d543c9350d287bb22) )
	ROM_REGION( 0x200000, "simm6.1", 0 )
	ROM_LOAD( "sfiii3-simm6.1", 0x00000, 0x200000, CRC(1c8c7ac4) SHA1(ac9f8353a4c356ef98aa7c226baba00b01f5a80f) )
	ROM_REGION( 0x200000, "simm6.2", 0 )
	ROM_LOAD( "sfiii3-simm6.2", 0x00000, 0x200000, CRC(a671341d) SHA1(636f4c04962bc1e1ddb29d2e01244b00389b234f) )
	ROM_REGION( 0x200000, "simm6.3", 0 )
	ROM_LOAD( "sfiii3-simm6.3", 0x00000, 0x200000, CRC(1a990249) SHA1(2acc639e2c0c53bf24096b8620eab090bc25d03b) )
	ROM_REGION( 0x200000, "simm6.4", 0 )
	ROM_LOAD( "sfiii3-simm6.4", 0x00000, 0x200000, CRC(20cb39ac) SHA1(7d13a0fea1ef719dd2ff77dfb547d53c6023cc9e) )
	ROM_REGION( 0x200000, "simm6.5", 0 )
	ROM_LOAD( "sfiii3-simm6.5", 0x00000, 0x200000, CRC(5f844b2f) SHA1(564e4934f89ed3b92a4c4874519f8f00f3b48696) )
	ROM_REGION( 0x200000, "simm6.6", 0 )
	ROM_LOAD( "sfiii3-simm6.6", 0x00000, 0x200000, CRC(450e8d28) SHA1(885db658132aa27926df617ec2d2a1f38abdbb60) )
	ROM_REGION( 0x200000, "simm6.7", 0 )
	ROM_LOAD( "sfiii3-simm6.7", 0x00000, 0x200000, CRC(cc5f4187) SHA1(248ddace21ed4736a56e92f77cc6ad219d7fef0b) )
ROM_END


ROM_START( sfiii3bh )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii3_japan_nocd.29f400.u2", 0x000000, 0x080000, CRC(1edc6366) SHA1(60b4b9adeb030a33059d74fdf03873029e465b52) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10bh",  0x0000000, 0x800000, CRC(b18be430) SHA1(0ede4ab7c950dc838e01b8df9b9ddd725ff640ee) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(5ca8faba) SHA1(71c12638ae7fa38b362d68c3ccb4bb3ccd67f0e9) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(b37cf960) SHA1(60310f95e4ecedee85846c08ccba71e286cda73b) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(450ec982) SHA1(1cb3626b8479997c4f1b29c41c81cac038fac31b) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(632c965f) SHA1(9a46b759f5dee35411fd6446c2457c084a6dfcd8) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(7a4c5f33) SHA1(f33cdfe247c7caf9d3d394499712f72ca930705e) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(8562358e) SHA1(8ed78f6b106659a3e4d94f38f8a354efcbdf3aa7) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(7baf234b) SHA1(38feb45d6315d771de5f9ae965119cb25bae2a1e) )
	ROM_LOAD( "60",  0x3000000, 0x800000, CRC(bc9487b7) SHA1(bc2cd2d3551cc20aa231bba425ff721570735eba) )
	ROM_LOAD( "61",  0x3800000, 0x800000, CRC(b813a1b1) SHA1(16de0ee3dfd6bf33d07b0ff2e797ebe2cfe6589e) )
ROM_END

ROM_START( sfiii3mh )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii3_japan_nocd.29f400.u2", 0x000000, 0x080000, CRC(1edc6366) SHA1(60b4b9adeb030a33059d74fdf03873029e465b52) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10",  0x0000000, 0x800000, CRC(ba7f76b2) SHA1(6b396596dea009b34af17484919ae37eda53ec65) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(5ca8faba) SHA1(71c12638ae7fa38b362d68c3ccb4bb3ccd67f0e9) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(b37cf960) SHA1(60310f95e4ecedee85846c08ccba71e286cda73b) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(450ec982) SHA1(1cb3626b8479997c4f1b29c41c81cac038fac31b) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(632c965f) SHA1(9a46b759f5dee35411fd6446c2457c084a6dfcd8) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(7a4c5f33) SHA1(f33cdfe247c7caf9d3d394499712f72ca930705e) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(8562358e) SHA1(8ed78f6b106659a3e4d94f38f8a354efcbdf3aa7) )
	ROM_LOAD( "51mh",  0x2800000, 0x800000, CRC(798b8f73) SHA1(96e81538b72302d799353f5a2c18ac957727d822) )
	ROM_LOAD( "60",  0x3000000, 0x800000, CRC(bc9487b7) SHA1(bc2cd2d3551cc20aa231bba425ff721570735eba) )
	ROM_LOAD( "61",  0x3800000, 0x800000, CRC(b813a1b1) SHA1(16de0ee3dfd6bf33d07b0ff2e797ebe2cfe6589e) )
ROM_END

ROM_START( sfiii3ng )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii3_japan_nocd.29f400.u2", 0x000000, 0x080000, CRC(1edc6366) SHA1(60b4b9adeb030a33059d74fdf03873029e465b52) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10g", 0x0000000, 0x800000, CRC(22cc7988) SHA1(35eedb2cea53d88a6212ecec9f9810c69736481e) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(5ca8faba) SHA1(71c12638ae7fa38b362d68c3ccb4bb3ccd67f0e9) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(b37cf960) SHA1(60310f95e4ecedee85846c08ccba71e286cda73b) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(450ec982) SHA1(1cb3626b8479997c4f1b29c41c81cac038fac31b) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(632c965f) SHA1(9a46b759f5dee35411fd6446c2457c084a6dfcd8) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(7a4c5f33) SHA1(f33cdfe247c7caf9d3d394499712f72ca930705e) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(8562358e) SHA1(8ed78f6b106659a3e4d94f38f8a354efcbdf3aa7) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(7baf234b) SHA1(38feb45d6315d771de5f9ae965119cb25bae2a1e) )
	ROM_LOAD( "60",  0x3000000, 0x800000, CRC(bc9487b7) SHA1(bc2cd2d3551cc20aa231bba425ff721570735eba) )
	ROM_LOAD( "61",  0x3800000, 0x800000, CRC(b813a1b1) SHA1(16de0ee3dfd6bf33d07b0ff2e797ebe2cfe6589e) )
ROM_END

ROM_START( sfiii3np )
	ROM_REGION32_BE( 0x080000, "bios", 0 )
	ROM_LOAD( "sfiii3_japan_nocd.29f400.u2", 0x000000, 0x080000, CRC(1edc6366) SHA1(60b4b9adeb030a33059d74fdf03873029e465b52) )

	ROM_REGION( 0x200000, "simm1.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm1.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm2.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm3.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm4.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm5.7", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.0", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.1", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.2", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.3", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.4", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.5", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.6", ROMREGION_ERASEFF )
	ROM_REGION( 0x200000, "simm6.7", ROMREGION_ERASEFF )

	ROM_REGION32_BE( USER4REGION_LENGTH, "old4", ROMREGION_ERASEFF )
	ROM_LOAD( "10p",  0x0000000, 0x800000, CRC(b13c6fa5) SHA1(5e8e3a3bfb2f5a18cf14a04e75a6abb5ddc807be) )
	ROM_LOAD( "20",  0x0800000, 0x800000, CRC(5ca8faba) SHA1(71c12638ae7fa38b362d68c3ccb4bb3ccd67f0e9) )
	ROM_REGION16_BE( USER5REGION_LENGTH, "old5", ROMREGION_ERASEFF )
	ROM_LOAD( "30",  0x0000000, 0x800000, CRC(b37cf960) SHA1(60310f95e4ecedee85846c08ccba71e286cda73b) )
	ROM_LOAD( "31",  0x0800000, 0x800000, CRC(450ec982) SHA1(1cb3626b8479997c4f1b29c41c81cac038fac31b) )
	ROM_LOAD( "40",  0x1000000, 0x800000, CRC(632c965f) SHA1(9a46b759f5dee35411fd6446c2457c084a6dfcd8) )
	ROM_LOAD( "41",  0x1800000, 0x800000, CRC(7a4c5f33) SHA1(f33cdfe247c7caf9d3d394499712f72ca930705e) )
	ROM_LOAD( "50",  0x2000000, 0x800000, CRC(8562358e) SHA1(8ed78f6b106659a3e4d94f38f8a354efcbdf3aa7) )
	ROM_LOAD( "51",  0x2800000, 0x800000, CRC(7baf234b) SHA1(38feb45d6315d771de5f9ae965119cb25bae2a1e) )
	ROM_LOAD( "60",  0x3000000, 0x800000, CRC(bc9487b7) SHA1(bc2cd2d3551cc20aa231bba425ff721570735eba) )
	ROM_LOAD( "61",  0x3800000, 0x800000, CRC(b813a1b1) SHA1(16de0ee3dfd6bf33d07b0ff2e797ebe2cfe6589e) )
ROM_END


ROM_START( sfiii4rd )
	ROM_REGION32_BE( 0x080000, "bios", 0 ) /* bios region */
	ROM_LOAD( "sfiii3_japan_nocd.29f400.u2", 0x000000, 0x080000, CRC(1edc6366) SHA1(60b4b9adeb030a33059d74fdf03873029e465b52) )

	ROM_REGION( 0x200000, "simm1.0", 0 )
	ROM_LOAD( "4rd-simm1.0", 0x00000, 0x200000, CRC(6bef26b4) SHA1(fb643d5fc5be4464374773a651ab4b5c51826047) ) // sldh
	ROM_REGION( 0x200000, "simm1.1", 0 )
	ROM_LOAD( "4rd-simm1.1", 0x00000, 0x200000, CRC(37ee88ed) SHA1(180e5ee309ad3898ac385b9add38fbec80cc1dce) ) // sldh
	ROM_REGION( 0x200000, "simm1.2", 0 )
	ROM_LOAD( "4rd-simm1.2", 0x00000, 0x200000, CRC(120139f0) SHA1(a5365ac00c75ee0e20f6c7b5a0bcee543c8582be) ) // sldh
	ROM_REGION( 0x200000, "simm1.3", 0 )
	ROM_LOAD( "4rd-simm1.3", 0x00000, 0x200000, CRC(b32e4fcc) SHA1(32bd359ca1747fa92691bd5471ba767456cc4dbb) ) // sldh

	ROM_REGION( 0x200000, "simm2.0", 0 )
	ROM_LOAD( "sfiii3-simm2.0", 0x00000, 0x200000, CRC(06eb969e) SHA1(d89f6a6585b76692d57d337f0f8186398fb056da) )
	ROM_REGION( 0x200000, "simm2.1", 0 )
	ROM_LOAD( "sfiii3-simm2.1", 0x00000, 0x200000, CRC(e7039f82) SHA1(8e81e66b5a4f45ae14b070a491bde47a6a74499f) )
	ROM_REGION( 0x200000, "simm2.2", 0 )
	ROM_LOAD( "sfiii3-simm2.2", 0x00000, 0x200000, CRC(645c96f7) SHA1(06d5a54874d4bf100b776131ec9060da209ad037) )
	ROM_REGION( 0x200000, "simm2.3", 0 )
	ROM_LOAD( "sfiii3-simm2.3", 0x00000, 0x200000, CRC(610efab1) SHA1(bbc21ed6ff6220ff6017a3f02ebd9a341fbc9040) )

	ROM_REGION( 0x200000, "simm3.0", 0 )
	ROM_LOAD( "sfiii3-simm3.0", 0x00000, 0x200000, CRC(7baa1f79) SHA1(3f409df28c24dd7221966b5340d59898ea756b6f) )
	ROM_REGION( 0x200000, "simm3.1", 0 )
	ROM_LOAD( "sfiii3-simm3.1", 0x00000, 0x200000, CRC(234bf8fe) SHA1(2191781ae4d726cab28de97f27efa4a13f3bdd69) )
	ROM_REGION( 0x200000, "simm3.2", 0 )
	ROM_LOAD( "sfiii3-simm3.2", 0x00000, 0x200000, CRC(d9ebc308) SHA1(af6a0dca77e5181c9f20533a06760a782c5fd51d) )
	ROM_REGION( 0x200000, "simm3.3", 0 )
	ROM_LOAD( "sfiii3-simm3.3", 0x00000, 0x200000, CRC(293cba77) SHA1(294604cacdc24261aec4d39e489de91c41fa1758) )
	ROM_REGION( 0x200000, "simm3.4", 0 )
	ROM_LOAD( "sfiii3-simm3.4", 0x00000, 0x200000, CRC(6055e747) SHA1(3813852c5a4a5355ef739ca8f0913bbd390b984b) )
	ROM_REGION( 0x200000, "simm3.5", 0 )
	ROM_LOAD( "sfiii3-simm3.5", 0x00000, 0x200000, CRC(499aa6fc) SHA1(5b9b6eab3e99ff3e1d7c1f50b9d8bc6a81f3f8a9) )
	ROM_REGION( 0x200000, "simm3.6", 0 )
	ROM_LOAD( "sfiii3-simm3.6", 0x00000, 0x200000, CRC(6c13879e) SHA1(de189b0b8f42bc7dd89983e62bc2ecb4237b3277) )
	ROM_REGION( 0x200000, "simm3.7", 0 )
	ROM_LOAD( "sfiii3-simm3.7", 0x00000, 0x200000, CRC(cf4f8ede) SHA1(e0fb68fcb0e445f824c62fa828d6e1dcd7e3683a) )

	ROM_REGION( 0x200000, "simm4.0", 0 )
	ROM_LOAD( "sfiii3-simm4.0", 0x00000, 0x200000, CRC(091fd5ba) SHA1(3327ad7c2623c119bf728af717ea2ce3b74673a9) )
	ROM_REGION( 0x200000, "simm4.1", 0 )
	ROM_LOAD( "sfiii3-simm4.1", 0x00000, 0x200000, CRC(0bca8917) SHA1(b7b284e2f16f46d46bcfaae779b232c5b980924f) )
	ROM_REGION( 0x200000, "simm4.2", 0 )
	ROM_LOAD( "sfiii3-simm4.2", 0x00000, 0x200000, CRC(a0fd578b) SHA1(100c9db9f00ecd88d518076f5a0822e6ac3695b3) )
	ROM_REGION( 0x200000, "simm4.3", 0 )
	ROM_LOAD( "sfiii3-simm4.3", 0x00000, 0x200000, CRC(4bf8c699) SHA1(2c0b4288b5ebc5e54d9e782dfc39eb8c78fd4c21) )
	ROM_REGION( 0x200000, "simm4.4", 0 )
	ROM_LOAD( "sfiii3-simm4.4", 0x00000, 0x200000, CRC(137b8785) SHA1(56a579520a8ce2abbf36be57777f024e80474eee) )
	ROM_REGION( 0x200000, "simm4.5", 0 )
	ROM_LOAD( "sfiii3-simm4.5", 0x00000, 0x200000, CRC(4fb70671) SHA1(9aba83c18cfc099a5ce18793119bff0c2b9c777f) )
	ROM_REGION( 0x200000, "simm4.6", 0 )
	ROM_LOAD( "sfiii3-simm4.6", 0x00000, 0x200000, CRC(832374a4) SHA1(c84629e32fbf47cb7b5b4ee7555bfc2ac9b3857f) )
	ROM_REGION( 0x200000, "simm4.7", 0 )
	ROM_LOAD( "sfiii3-simm4.7", 0x00000, 0x200000, CRC(1c88576d) SHA1(0f039944d0c2305999ed5dbd351c3eb87812dc3b) )

	ROM_REGION( 0x200000, "simm5.0", 0 )
	ROM_LOAD( "sfiii3-simm5.0", 0x00000, 0x200000, CRC(c67d9190) SHA1(d265475244099d0ec153059986f3445c7bd910a3) )
	ROM_REGION( 0x200000, "simm5.1", 0 )
	ROM_LOAD( "sfiii3-simm5.1", 0x00000, 0x200000, CRC(6cb79868) SHA1(c94237f30e05bfcb2e23945530c812d9e4c73416) )
	ROM_REGION( 0x200000, "simm5.2", 0 )
	ROM_LOAD( "sfiii3-simm5.2", 0x00000, 0x200000, CRC(df69930e) SHA1(c76b7c559a1d5558138afbc796249efa2f49f6a8) )
	ROM_REGION( 0x200000, "simm5.3", 0 )
	ROM_LOAD( "sfiii3-simm5.3", 0x00000, 0x200000, CRC(333754e0) SHA1(4c18a569c26524a492ecd6f4c8b3c8e803a077d3) )
	ROM_REGION( 0x200000, "simm5.4", 0 )
	ROM_LOAD( "sfiii3-simm5.4", 0x00000, 0x200000, CRC(78f6d417) SHA1(a69577cc5399fcf0a24548661168f27f3e7e8e40) )
	ROM_REGION( 0x200000, "simm5.5", 0 )
	ROM_LOAD( "sfiii3-simm5.5", 0x00000, 0x200000, CRC(8ccad9b1) SHA1(f8bda399f87be2497b7ac39e9661f9863bf4f873) )
	ROM_REGION( 0x200000, "simm5.6", 0 )
	ROM_LOAD( "4rd-simm5.6", 0x00000, 0x200000, CRC(e9b61a56) SHA1(9277ac5da4715aa5325ae9f8c055f1e826b4ce54) )
	ROM_REGION( 0x200000, "simm5.7", 0 )
	ROM_LOAD( "4rd-simm5.7", 0x00000, 0x200000, CRC(8db3a249) SHA1(db38963ce011535a95f11426c17fb3eeda300917) )

	ROM_REGION( 0x200000, "simm6.0", 0 )
	ROM_LOAD( "sfiii3-simm6.0", 0x00000, 0x200000, CRC(8da69042) SHA1(fd3d08295342635b2136e48d543c9350d287bb22) )
	ROM_REGION( 0x200000, "simm6.1", 0 )
	ROM_LOAD( "sfiii3-simm6.1", 0x00000, 0x200000, CRC(1c8c7ac4) SHA1(ac9f8353a4c356ef98aa7c226baba00b01f5a80f) )
	ROM_REGION( 0x200000, "simm6.2", 0 )
	ROM_LOAD( "sfiii3-simm6.2", 0x00000, 0x200000, CRC(a671341d) SHA1(636f4c04962bc1e1ddb29d2e01244b00389b234f) )
	ROM_REGION( 0x200000, "simm6.3", 0 )
	ROM_LOAD( "sfiii3-simm6.3", 0x00000, 0x200000, CRC(1a990249) SHA1(2acc639e2c0c53bf24096b8620eab090bc25d03b) )
	ROM_REGION( 0x200000, "simm6.4", 0 )
	ROM_LOAD( "sfiii3-simm6.4", 0x00000, 0x200000, CRC(20cb39ac) SHA1(7d13a0fea1ef719dd2ff77dfb547d53c6023cc9e) )
	ROM_REGION( 0x200000, "simm6.5", 0 )
	ROM_LOAD( "sfiii3-simm6.5", 0x00000, 0x200000, CRC(5f844b2f) SHA1(564e4934f89ed3b92a4c4874519f8f00f3b48696) )
	ROM_REGION( 0x200000, "simm6.6", 0 )
	ROM_LOAD( "sfiii3-simm6.6", 0x00000, 0x200000, CRC(450e8d28) SHA1(885db658132aa27926df617ec2d2a1f38abdbb60) )
	ROM_REGION( 0x200000, "simm6.7", 0 )
	ROM_LOAD( "sfiii3-simm6.7", 0x00000, 0x200000, CRC(cc5f4187) SHA1(248ddace21ed4736a56e92f77cc6ad219d7fef0b) )
ROM_END



GAME( 2009, jojobbh2,  jojoba,   jojoba,   cps3_jojo, cps3_hbmame, jojoban,   ROT0, "Pipi899", "JoJo's Bizarre Adventure (Boss v2.0 hack by Pipi899 2009-08-08)", 0 )
GAME( 2009, jojobbss,  jojoba,   jojoba,   cps3_jojo, cps3_hbmame, jojoban,   ROT0, "Pipi899", "JoJo's Bizarre Adventure (Boss hack by Pipi899 2009-07-15)", 0 )
GAME( 2009, jojobpow,  jojoba,   jojoba,   cps3_jojo, cps3_hbmame, jojoban,   ROT0, "Pipi899", "JoJo's Bizarre Adventure (Power hack by Pipi899 2009-07-15)", 0 )
GAME( 2009, jojonbss,  jojo,     jojo,     cps3_jojo, cps3_hbmame, jojon,     ROT0, "Pipi899", "JoJo's Venture (Boss hack by Pipi899 2009-07-09)", 0 )
GAME( 2009, jojonpow,  jojo,     jojo,     cps3_jojo, cps3_hbmame, jojon,     ROT0, "Pipi899", "JoJo's Venture (Power hack by Pipi899 2009-07-11)", 0 )
GAME( 1996, redeartn,  redearth, redeartn, cps3_ren,  cps3_state,  redearth,  ROT0, "Capcom", "Red Earth (Asia 961121, NO CD)", 0 )
GAME( 1996, redeartno, redearth, redeartn, cps3_ren,  cps3_hbmame, redeartno, ROT0, "Capcom", "Red Earth (Euro 961121, NO CD)", 0 )
GAME( 2009, redearex,  redearth, redeartn, cps3_ren,  cps3_hbmame, redeartno, ROT0, "Pipi899", "Red Earth (Ex Super Version hack by Pipi899 2009-09-08)", 0 )
GAME( 2009, sfiiibhp,  sfiii,    sfiii,    cps3,      cps3_hbmame, sfiiin,    ROT0, "Pipi899", "Street Fighter III: New Generation (Boss hack by Pipi899 2009-08-08)", 0 )
GAME( 2009, sfiiipmp,  sfiii,    sfiii,    cps3,      cps3_hbmame, sfiiin,    ROT0, "Pipi899", "Street Fighter III: New Generation (Power hack by Pipi899 2009-07-06)", 0 )
GAMEL(1997, sfiii2bh,  sfiii2,   sfiii2,   cps3,      cps3_hbmame, sfiii2n,   ROT0, "Yumeji", "Street Fighter III 2nd Impact: Giant Attack (Boss hack by Yumeji)", 0, layout_sfiii2 )
GAMEL(2009, sfiii2np,  sfiii2,   sfiii2,   cps3,      cps3_hbmame, sfiii2n,   ROT0, "Pipi899", "Street Fighter III 2nd Impact: Giant Attack (Power hack by Pipi899 2009-07-14)", 0, layout_sfiii2 )
GAMEL(1997, sfiii2pl,  sfiii2,   sfiii2,   cps3,      cps3_hbmame, sfiii2n,   ROT0, "Krysofun", "Street Fighter III 2nd Impact: Giant Attack (Plus v1.0 hack by Krysofun)", 0, layout_sfiii2 )
GAME( 2013, sfiii3an,  sfiii3,   sfiii3,   cps3,      cps3_state,  sfiii3,    ROT0, "hack",   "Street Fighter III 3rd Strike: Ford Strike (Japan 990608, NO CD)", 0 )
GAME( 1999, sfiii3bh,  sfiii3,   sfiii3,   cps3,      cps3_hbmame, sfiii3n,   ROT0, "Yumeji", "Street Fighter III 3rd Strike: Fight for the Future (Boss hack by Yumeji)", 0 )
GAME( 1999, sfiii3mh,  sfiii3,   sfiii3,   cps3,      cps3_hbmame, sfiii3n,   ROT0, "hack", "Street Fighter III 3rd Strike: Fight for the Future (Makoto Color hack)", 0 )
GAME( 2009, sfiii3ng,  sfiii3,   sfiii3,   cps3,      cps3_hbmame, sfiii3n,   ROT0, "Pipi899", "Street Fighter III 3rd Strike: Fight for the Future (Gill Unable Reactivating hack by Pipi899 2009-07-14)", 0 )
GAME( 2009, sfiii3np,  sfiii3,   sfiii3,   cps3,      cps3_hbmame, sfiii3n,   ROT0, "Pipi899", "Street Fighter III 3rd Strike: Fight for the Future (Power hack by Pipi899 2009-07-14)", 0 )
GAME( 2013, sfiii4rd,  sfiii3,   sfiii3,   cps3,      cps3_state,  sfiii3,    ROT0, "hack",   "Street Fighter III 3rd Strike: 4rd Arrange Edition (Japan 990608, NO CD)", 0 )
